@@ -72,13 +72,34 @@ class RemoteServer:
 
 
 @contextmanager
-def ssh_cfg(alias=None):
-    ssh_user = os.getenv('SSH_USER')
-    ssh_host = os.getenv('SSH_HOST')
-    ssh_alias = alias or ssh_host
-    ssh_pkey = base64.b64decode(os.getenv('SSH_KEY'))
-    ssh_pub_key = base64.b64decode(os.getenv('SSH_PUB_KEY'))
-    ssh_key_fname = os.getenv('SSH_KEY_FILE')
+def ssh_cfg(**kwargs):
+    """
+    Generating temporary SSH config and dumps ssh keys in temp dir
+
+    Parameters
+    ----------
+    host : str, 'localhost'
+        SSH host, by default is None. If none trying to read env parameter `SSH_HOST`
+    user : str, 'guest'
+        SSH user, by default is None. If none trying to read env parameter `SSH_USER`
+    pkey : str
+        Private key, encoded by Base64, by default is None. If none trying to read env parameter `SSH_KEY`
+    pub_key : str
+        Public key, encoded by Base64, by default is None. If none trying to read env parameter `SSH_PUB_KEY`
+    key_fname : str, 'id_rsa'
+        Key filename, by default is `id_rsa`.
+
+    Yields
+    ------
+    conf_path : str
+        Temporary SSH Config file location
+    """
+    ssh_user = kwargs.get('user') or os.getenv('SSH_USER', 'guest')
+    ssh_host = kwargs.get('host') or os.getenv('SSH_HOST', 'localhost')
+    ssh_alias = kwargs.get('alias') or ssh_host
+    ssh_pkey = base64.b64decode(kwargs.get('pkey') or os.getenv('SSH_KEY'))
+    ssh_pub_key = base64.b64decode(kwargs.get('pub_key') or os.getenv('SSH_PUB_KEY'))
+    ssh_key_fname = kwargs.get('key_fname') or os.getenv('SSH_KEY_FILE', 'id_rsa')
 
     with tempfile.TemporaryDirectory() as tmpdir:
         tmpdir_ = Path(tmpdir)
@@ -103,4 +124,8 @@ Host {ssh_alias}
     IdentityFile    {pkey_path}
 ''')
 
+        pkey_path.chmod(0o600)
+        pubkey_path.chmod(0o600)
+        conf_path.chmod(0o600)
+
         yield str(conf_path)
